@@ -22,6 +22,10 @@
 #include <mpatrol.h>
 #endif
 
+#ifdef __APPLE__
+#include "TargetConditionals.h"
+#endif
+
 #include "eXosip2.h"
 #include <eXosip2/eXosip.h>
 
@@ -72,23 +76,20 @@ _eXosip_transaction_init(osip_transaction_t ** transaction,
 						 osip_fsm_type_t ctx_type, osip_t * osip,
 						 osip_message_t * message)
 {
-#ifdef SRV_RECORD
-	osip_srv_record_t record;
-#endif
 	int i;
 	i = osip_transaction_init(transaction, ctx_type, osip, message);
 	if (i != 0) {
 		return i;
 	}
-#ifdef SRV_RECORD
-	memset(&record, 0, sizeof(osip_srv_record_t));
-	i = _eXosip_srv_lookup(*transaction, message, &record);
-	if (i < 0) {
-		/* might be a simple DNS request or an IP */
-		return OSIP_SUCCESS;
+	{
+		osip_naptr_t *naptr_record=NULL;
+		i = _eXosip_srv_lookup(message, &naptr_record);
+		if (i < 0) {
+			/* might be a simple DNS request or an IP */
+			return OSIP_SUCCESS;
+		}
+		osip_transaction_set_naptr_record(*transaction, naptr_record);
 	}
-	osip_transaction_set_srv_record(*transaction, &record);
-#endif
 	return OSIP_SUCCESS;
 }
 
@@ -518,13 +519,23 @@ static int _eXosip_retry_notify_with_auth(eXosip_event_t * je)
 
 static int eXosip_retry_with_auth(eXosip_event_t * je)
 {
+	int res=OSIP_UNDEFINED_ERROR;
 	if (!je || !je->request || !je->response)
 		return OSIP_BADPARAMETER;
 
 	if (je->rid > 0) {
 		return _eXosip_retry_register_with_auth(je);
 	} else if (je->cid > 0) {
-		return _eXosip_retry_invite_with_auth(je);
+		res = _eXosip_retry_invite_with_auth(je);
+		if (res==OSIP_NOTFOUND)
+		{
+			osip_transaction_t *tr = NULL;
+			eXosip_transaction_find(je->tid, &tr);
+			if (tr != NULL) {
+				return _eXosip_retry_with_auth(NULL, &tr, NULL);
+			}
+		}
+		return res;
 	}
 #ifndef MINISIZE
 	else if (je->sid > 0) {
@@ -603,7 +614,7 @@ void eXosip_automatic_refresh(void)
 					out_tr = js->s_out_tr;
 
 				if (js->s_reg_period == 0 || out_tr == NULL) {
-				} else if (now - out_tr->birth_time > js->s_reg_period - 75) {	/* will expires in 75 sec: send refresh! */
+				} else if (now - out_tr->birth_time > js->s_reg_period - (js->s_reg_period/10)) {	/* will expires in js->s_reg_period/10: send refresh! */
 					int i;
 
 					i = _eXosip_subscribe_automatic_refresh(js, jd, out_tr);
@@ -624,8 +635,12 @@ void eXosip_automatic_refresh(void)
 			} else if (now - jr->r_last_tr->birth_time > 900) {
 				/* automatic refresh */
 				eXosip_register_send_register(jr->r_id, NULL);
-			} else if (now - jr->r_last_tr->birth_time > jr->r_reg_period - 75) {
-				/* automatic refresh */
+#if TARGET_OS_IPHONE
+			} else if (now - jr->r_last_tr->birth_time > jr->r_reg_period - 630) {
+				eXosip_register_send_register(jr->r_id, NULL);
+#endif
+			} else if (now - jr->r_last_tr->birth_time > jr->r_reg_period - (jr->r_reg_period/10)) {
+				/* automatic refresh at "timeout - 10%" */
 				eXosip_register_send_register(jr->r_id, NULL);
 			} else if (now - jr->r_last_tr->birth_time > 120 &&
 					   (jr->r_last_tr->last_response == NULL
@@ -904,7 +919,8 @@ void eXosip_automatic_action(void)
 				out_tr->orig_request != NULL &&
 				out_tr->last_response != NULL &&
 				(out_tr->last_response->status_code == 401
-				 || out_tr->last_response->status_code == 407)) {
+				 || out_tr->last_response->status_code == 407
+				 || out_tr->last_response->status_code == 423)) {
 				/* retry with credential */
 				if (js->s_retry < 3) {
 					int i;
@@ -953,7 +969,7 @@ void eXosip_automatic_action(void)
 							jd->d_retry++;
 						}
 					} else if (js->s_reg_period == 0 || out_tr == NULL) {
-					} else if (now - out_tr->birth_time > js->s_reg_period - 75) {	/* will expires in 75 sec: send refresh! */
+					} else if (now - out_tr->birth_time > js->s_reg_period - (js->s_reg_period/10)) {	/* will expires in js->s_reg_period/10 sec: send refresh! */
 						int i;
 
 						i = _eXosip_subscribe_automatic_refresh(js, jd, out_tr);
@@ -1013,7 +1029,7 @@ void eXosip_automatic_action(void)
 				/* automatic refresh */
 				eXosip_register_send_register(jr->r_id, NULL);
 			} else if (jr->r_reg_period != 0
-					   && now - jr->r_last_tr->birth_time > jr->r_reg_period - 75)
+					   && now - jr->r_last_tr->birth_time > jr->r_reg_period - (jr->r_reg_period/10))
 			{
 				/* automatic refresh */
 				eXosip_register_send_register(jr->r_id, NULL);
@@ -1048,7 +1064,7 @@ void eXosip_automatic_action(void)
 				/* automatic refresh */
 				_eXosip_publish_refresh(NULL, &jpub->p_last_tr, NULL);
 			} else if (jpub->p_period != 0
-					   && now - jpub->p_last_tr->birth_time > jpub->p_period - 75)
+					   && now - jpub->p_last_tr->birth_time > jpub->p_period - (jpub->p_period/10))
 			{
 				/* automatic refresh */
 				_eXosip_publish_refresh(NULL, &jpub->p_last_tr, NULL);
@@ -1482,7 +1498,24 @@ int eXosip_update_top_via(osip_message_t * sip)
 	osip_free(br->gvalue);
 	number = osip_build_random_number();
 
-	sprintf(tmp, "z9hG4bK%u", number);
+	snprintf(tmp, 40, "z9hG4bK%u", number);
 	br->gvalue = osip_strdup(tmp);
 	return OSIP_SUCCESS;
 }
+
+/* vivox: mark all registrations as needing refreshing */
+void eXosip_mark_all_registrations_expired()
+{
+	eXosip_reg_t *jr;
+	int wakeup = 0;
+
+	for (jr = eXosip.j_reg; jr != NULL; jr = jr->next) {
+		if (jr->r_id >= 1 && jr->r_last_tr != NULL) {
+			jr->r_last_tr->birth_time -= jr->r_reg_period;
+			wakeup = 1;
+		}
+	}
+	if (wakeup) {
+		__eXosip_wakeup ();
+	}
+}
