@@ -80,7 +80,7 @@
 
 #endif
 
-#define EXOSIP_VERSION	"3.3.0"
+#define EXOSIP_VERSION	"3.6.0"
 
 #ifdef __cplusplus
 extern "C" {
@@ -237,7 +237,8 @@ extern "C" {
 		char *r_contact;		/* list of contacts string */
 
 		char r_line[16];		/* line identifier */
-
+		char r_qvalue[16];		/* the q value used for routing */
+		
 		osip_transaction_t *r_last_tr;
 		int r_retry;			/* avoid too many unsuccessfull retry */
 
@@ -440,6 +441,7 @@ extern "C" {
 		jauthinfo_t *authinfos;
 
 		int keep_alive;
+		int keep_alive_options;
 		int learn_port;
 #ifndef MINISIZE
 		int http_port;
@@ -449,6 +451,7 @@ extern "C" {
 #endif
 		int use_rport;
 		int dns_capabilities;
+		int dscp;
 		char ipv4_for_gateway[256];
 		char ipv6_for_gateway[256];
 #ifndef MINISIZE
@@ -529,6 +532,8 @@ extern "C" {
 	int _eXosip_request_add_via(osip_message_t * request, const char *transport,
 								const char *locip);
 
+	void eXosip_mark_all_registrations_expired ();
+
 	int eXosip_add_authentication_information(osip_message_t * req,
 											  osip_message_t * last_response);
 	int _eXosip_reg_find(eXosip_reg_t ** reg, osip_transaction_t * tr);
@@ -673,8 +678,9 @@ extern "C" {
 								 osip_fsm_type_t ctx_type, osip_t * osip,
 								 osip_message_t * message);
 
-	int _eXosip_srv_lookup(osip_transaction_t * tr, osip_message_t * sip,
-						   struct osip_srv_record *record);
+	int _eXosip_srv_lookup(osip_message_t * sip, osip_naptr_t **naptr_record);
+
+	void _eXosip_dnsutils_release(osip_naptr_t *naptr_record);
 
 	int _eXosip_handle_incoming_message(char *buf, size_t len, int socket,
 										char *host, int port);
