@@ -125,7 +125,7 @@ _eXosip_register_build_register(eXosip_reg_t * jr, osip_message_t ** _reg)
 						osip_message_free(last_response);
 					return OSIP_NOMEM;
 				}
-				sprintf(reg->cseq->number, "%i", osip_cseq_num);
+				snprintf(reg->cseq->number, length + 2, "%i", osip_cseq_num);
 
 
 				if (last_response != NULL && last_response->status_code == 423) {
@@ -194,8 +194,9 @@ _eXosip_register_build_register(eXosip_reg_t * jr, osip_message_t ** _reg)
 }
 
 int
-eXosip_register_build_initial_register(const char *from, const char *proxy,
+eXosip_register_build_initial_register_withqvalue(const char *from, const char *proxy,
 									   const char *contact, int expires,
+									   const char *qvalue,
 									   osip_message_t ** reg)
 {
 	eXosip_reg_t *jr = NULL;
@@ -206,6 +207,7 @@ eXosip_register_build_initial_register(const char *from, const char *proxy,
 	if (from == NULL || proxy == NULL)
 		return OSIP_BADPARAMETER;
 
+#ifdef REJECT_DOUBLE_REGISTRATION
 	/* Avoid adding the same registration info twice to prevent mem leaks */
 	for (jr = eXosip.j_reg; jr != NULL; jr = jr->next) {
 		if (strcmp(jr->r_aor, from) == 0 && strcmp(jr->r_registrar, proxy) == 0) {
@@ -215,6 +217,8 @@ eXosip_register_build_initial_register(const char *from, const char *proxy,
 			break;
 		}
 	}
+#endif
+
 	if (jr == NULL) {
 		/* Add new registration info */
 		i = eXosip_reg_init(&jr, from, proxy, contact);
@@ -231,8 +235,11 @@ eXosip_register_build_initial_register(const char *from, const char *proxy,
 	jr->r_reg_period = expires;
 	if (jr->r_reg_period <= 0)	/* too low */
 		jr->r_reg_period = 0;
-	else if (jr->r_reg_period < 100)	/* too low */
-		jr->r_reg_period = 100;
+	else if (jr->r_reg_period < 30)	/* too low */
+		jr->r_reg_period = 30;
+
+	if(qvalue)
+		osip_strncpy(jr->r_qvalue, qvalue, sizeof(jr->r_qvalue));
 
 	i = _eXosip_register_build_register(jr, reg);
 	if (i != 0) {
@@ -246,6 +253,14 @@ eXosip_register_build_initial_register(const char *from, const char *proxy,
 	return jr->r_id;
 }
 
+int
+eXosip_register_build_initial_register(const char *from, const char *proxy,
+									   const char *contact, int expires,
+									   osip_message_t ** reg)
+{
+	return eXosip_register_build_initial_register_withqvalue(from, proxy, contact, expires, NULL, reg);
+}
+
 int eXosip_register_build_register(int rid, int expires, osip_message_t ** reg)
 {
 	eXosip_reg_t *jr;
@@ -264,8 +279,8 @@ int eXosip_register_build_register(int rid, int expires, osip_message_t ** reg)
 	} /* unregistration */
 	else if (jr->r_reg_period > 3600)
 		jr->r_reg_period = 3600;
-	else if (jr->r_reg_period < 100)	/* too low */
-		jr->r_reg_period = 100;
+	else if (jr->r_reg_period < 30)	/* too low */
+		jr->r_reg_period = 30;
 
 	if (jr->r_last_tr != NULL) {
 		if (jr->r_last_tr->state != NICT_TERMINATED
